@@ -85,9 +85,15 @@ def actions_ci(self):
 
     # Check that the action is turned on for the correct events
     try:
-        expected = {"push": {"branches": ["dev"]}, "pull_request": None, "release": {"types": ["published"]}}
         # NB: YAML dict key 'on' is evaluated to a Python dict key True
-        assert ciwf[True] == expected
+        assert "dev" in ciwf[True]["push"]["branches"]
+        pr_subtree = ciwf[True]["pull_request"]
+        assert (
+            pr_subtree == None
+            or ("branches" in pr_subtree and "dev" in pr_subtree["branches"])
+            or ("ignore_branches" in pr_subtree and not "dev" in pr_subtree["ignore_branches"])
+        )
+        assert "published" in ciwf[True]["release"]["types"]
     except (AssertionError, KeyError, TypeError):
         failed.append("'.github/workflows/ci.yml' is not triggered on expected events")
     else:
@@ -131,7 +137,7 @@ def actions_ci(self):
     # Check that we are testing the minimum nextflow version
     try:
         matrix = ciwf["jobs"]["test"]["strategy"]["matrix"]["include"]
-        assert any([i["NXF_VER"] == self.minNextflowVersion for i in matrix])
+        assert any([i.get("NXF_VER") == self.minNextflowVersion for i in matrix])
     except (KeyError, TypeError):
         failed.append("'.github/workflows/ci.yml' does not check minimum NF version")
     except AssertionError:
