@@ -19,13 +19,23 @@ import subprocess
 import yaml
 
 import nf_core.utils
+import nf_core.modules.module_utils
 
 log = logging.getLogger(__name__)
 
 
 class ModuleCreate(object):
     def __init__(
-        self, directory=".", tool="", author=None, process_label=None, has_meta=None, force=False, conda_name=None
+        self,
+        directory=".",
+        tool="",
+        author=None,
+        process_label=None,
+        has_meta=None,
+        force=False,
+        conda_name=None,
+        conda_version=None,
+        repo_type=None,
     ):
         self.directory = directory
         self.tool = tool
@@ -35,8 +45,9 @@ class ModuleCreate(object):
         self.force_overwrite = force
         self.subtool = None
         self.tool_conda_name = conda_name
+        self.tool_conda_version = conda_version
         self.tool_licence = None
-        self.repo_type = None
+        self.repo_type = repo_type
         self.tool_licence = ""
         self.tool_description = ""
         self.tool_doc_url = ""
@@ -75,9 +86,12 @@ class ModuleCreate(object):
 
         # Check whether the given directory is a nf-core pipeline or a clone of nf-core/modules
         try:
-            self.repo_type = self.get_repo_type(self.directory)
+            self.directory, self.repo_type = nf_core.modules.module_utils.get_repo_type(self.directory, self.repo_type)
         except LookupError as e:
             raise UserWarning(e)
+        log.info(f"Repository type: [blue]{self.repo_type}")
+        if self.directory != ".":
+            log.info(f"Base directory: '{self.directory}'")
 
         log.info(
             "[yellow]Press enter to use default values [cyan bold](shown in brackets)[/] [yellow]or type your own responses. "
@@ -131,9 +145,14 @@ class ModuleCreate(object):
                     anaconda_response = nf_core.utils.anaconda_package(self.tool_conda_name, ["bioconda"])
                 else:
                     anaconda_response = nf_core.utils.anaconda_package(self.tool, ["bioconda"])
-                version = anaconda_response.get("latest_version")
-                if not version:
-                    version = str(max([parse_version(v) for v in anaconda_response["versions"]]))
+
+                if not self.tool_conda_version:
+                    version = anaconda_response.get("latest_version")
+                    if not version:
+                        version = str(max([parse_version(v) for v in anaconda_response["versions"]]))
+                else:
+                    version = self.tool_conda_version
+
                 self.tool_licence = nf_core.utils.parse_anaconda_licence(anaconda_response, version)
                 self.tool_description = anaconda_response.get("summary", "")
                 self.tool_doc_url = anaconda_response.get("doc_url", "")
@@ -217,7 +236,7 @@ class ModuleCreate(object):
             )
         while self.has_meta is None:
             self.has_meta = rich.prompt.Confirm.ask(
-                "[violet]Will the module require a meta map of sample information? (yes/no)", default=True
+                "[violet]Will the module require a meta map of sample information?", default=True
             )
 
         # Create module template with cokiecutter
@@ -272,29 +291,6 @@ class ModuleCreate(object):
             template_stat = os.stat(os.path.join(os.path.dirname(nf_core.__file__), "module-template", template_fn))
             os.chmod(dest_fn, template_stat.st_mode)
 
-    def get_repo_type(self, directory):
-        """
-        Determine whether this is a pipeline repository or a clone of
-        nf-core/modules
-        """
-        # Verify that the pipeline dir exists
-        if dir is None or not os.path.exists(directory):
-            raise UserWarning(f"Could not find directory: {directory}")
-
-        readme = os.path.join(directory, "README.md")
-        # Determine repository type
-        if os.path.exists(readme):
-            with open(readme) as fh:
-                if fh.readline().rstrip().startswith("# ![nf-core/modules]"):
-                    return "modules"
-                else:
-                    return "pipeline"
-        else:
-            raise UserWarning(
-                f"This directory does not look like a clone of nf-core/modules or an nf-core pipeline: '{directory}'"
-                " Please point to a valid directory."
-            )
-
     def get_module_dirs(self):
         """Given a directory and a tool/subtool, set the file paths and check if they already exist
 
